# CRON_LOG.md - Scheduled Task History

| Timestamp | Task ID | Status | Message |
|-----------|---------|--------|---------|

### [2026-03-09 18:34:31] Heartbeat (`heartbeat`)

❌ ERROR: status_code: 400, model_name: qwen/qwen3.5-35b-a3b, body: Error rendering prompt with jinja template: "No user query found in messages.".

This is usually an issue with the model's prompt template. If you are using a popular model, you can try to search the model under lmstudio-community, which will have fixed prompt templates. If you cannot find one, you are welcome to post this issue to our discord or issue tracker on GitHub. Alternatively, if you know how to write jinja templates, you can override the prompt template in My Models > model settings > Prompt Template.

---

### [2026-03-09 19:04:31] Heartbeat (`heartbeat`)

❌ ERROR: status_code: 400, model_name: qwen/qwen3.5-35b-a3b, body: Error rendering prompt with jinja template: "No user query found in messages.".

This is usually an issue with the model's prompt template. If you are using a popular model, you can try to search the model under lmstudio-community, which will have fixed prompt templates. If you cannot find one, you are welcome to post this issue to our discord or issue tracker on GitHub. Alternatively, if you know how to write jinja templates, you can override the prompt template in My Models > model settings > Prompt Template.

---

### [2026-03-09 19:34:31] Heartbeat (`heartbeat`)

❌ ERROR: status_code: 400, model_name: qwen/qwen3.5-35b-a3b, body: Error rendering prompt with jinja template: "No user query found in messages.".

This is usually an issue with the model's prompt template. If you are using a popular model, you can try to search the model under lmstudio-community, which will have fixed prompt templates. If you cannot find one, you are welcome to post this issue to our discord or issue tracker on GitHub. Alternatively, if you know how to write jinja templates, you can override the prompt template in My Models > model settings > Prompt Template.

---
